VisualizationTaskOutput

Enum VisualizationTaskOutput 

pub enum VisualizationTaskOutput {
    ScalarFieldUpdate {
        layer_name: String,
        values: Vec<f32>,
    },
    ColumnUpdate {
        layer_name: String,
        columns: ColumnInstanceSet,
        ramp: ColorRamp,
    },
    PointCloudUpdate {
        layer_name: String,
        points: PointInstanceSet,
        ramp: ColorRamp,
    },
}
Output of an asynchronous visualization preprocessing task.

Contains the preprocessed data ready to be applied to a layer via the corresponding MapState::set_* method.

Variants



ScalarFieldUpdate

Preprocessed scalar field values (for grid scalar / grid extrusion).

Fields

layer_name: String

Layer name to update.

values: Vec<f32>

New scalar values.



ColumnUpdate

Preprocessed column instances (for instanced column layers).

Fields

layer_name: String

Layer name to update.

columns: ColumnInstanceSet

New column instance set.

ramp: ColorRamp

Colour ramp (included in case the ramp changes with the data).



PointCloudUpdate

Preprocessed point instances (for point cloud layers).

Fields

layer_name: String

Layer name to update.

points: PointInstanceSet

New point instance set.

ramp: ColorRamp

Colour ramp.