TileLifecycleEventKind

Enum TileLifecycleEventKind 

pub enum TileLifecycleEventKind {
    Selected,
    Queued,
    Dispatched,
    Completed,
    Decoded,
    PromotedToCache,
    UsedAsExact,
    UsedAsFallback,
    CancelledAsStale,
    EvictedWhilePending,
    EvictedAfterRenderableUse,
    Failed,
}
Lifecycle transition kind.

Variants



Selected

Tile entered the desired set for the current frame.



Queued

Tile was inserted into the pending queue.



Dispatched

Tile request was dispatched to the source transport.



Completed

Tile fetch completed and returned to the engine.



Decoded

Tile payload passed validation / decode stage.



PromotedToCache

Tile was promoted into the cache as renderable payload.



UsedAsExact

Tile was used as the exact visible tile.



UsedAsFallback

Tile was used as fallback imagery for another target.



CancelledAsStale

Tile request was cancelled because it became stale.



EvictedWhilePending

Tile was evicted while still pending.



EvictedAfterRenderableUse

Tile was evicted after it had renderable payload.



Failed

Tile failed to load or validate.