NumericExpression

Enum NumericExpression 

pub enum NumericExpression {
Show 16 variants Literal(f64), Zoom, Pitch, GetProperty { key: String, fallback: f64, }, GetState { key: String, fallback: f64, }, Add(Box<NumericExpression>, Box<NumericExpression>), Sub(Box<NumericExpression>, Box<NumericExpression>), Mul(Box<NumericExpression>, Box<NumericExpression>), Div(Box<NumericExpression>, Box<NumericExpression>), Mod(Box<NumericExpression>, Box<NumericExpression>), Pow(Box<NumericExpression>, Box<NumericExpression>), Abs(Box<NumericExpression>), Ln(Box<NumericExpression>), Sqrt(Box<NumericExpression>), Min(Box<NumericExpression>, Box<NumericExpression>), Max(Box<NumericExpression>, Box<NumericExpression>),
}
A numeric expression that evaluates to f64.

Used as the input for Interpolate and Step expressions, and as operands for arithmetic and comparison operations.

Variants



Literal(f64)

A constant numeric literal.



Zoom

The current map zoom level.



Pitch

The current camera pitch in degrees.



GetProperty

Read a numeric feature property.

Fields

key: String

Property key.

fallback: f64

Fallback when absent or non-numeric.



GetState

Read a numeric feature-state value.

Fields

key: String

State key.

fallback: f64

Fallback when absent or non-numeric.



Add(Box<NumericExpression>, Box<NumericExpression>)

Addition: a + b.



Sub(Box<NumericExpression>, Box<NumericExpression>)

Subtraction: a - b.



Mul(Box<NumericExpression>, Box<NumericExpression>)

Multiplication: a * b.



Div(Box<NumericExpression>, Box<NumericExpression>)

Division: a / b (returns 0 on division by zero).



Mod(Box<NumericExpression>, Box<NumericExpression>)

Remainder: a % b.



Pow(Box<NumericExpression>, Box<NumericExpression>)

Exponentiation: a ^ b.



Abs(Box<NumericExpression>)

Absolute value.



Ln(Box<NumericExpression>)

Natural logarithm.



Sqrt(Box<NumericExpression>)

Square root.



Min(Box<NumericExpression>, Box<NumericExpression>)

Minimum of two values.



Max(Box<NumericExpression>, Box<NumericExpression>)

Maximum of two values.

Implementations

Source

impl NumericExpression

pub fn eval(&self, ctx: &ExprEvalContext<'_>) -> f64

Evaluate this numeric expression against a context.