TilePipelineDiagnostics

Struct TilePipelineDiagnostics 

pub struct TilePipelineDiagnostics {
    pub layer_name: String,
    pub visible_tiles: usize,
    pub visible_loaded_tiles: usize,
    pub visible_fallback_tiles: usize,
    pub visible_missing_tiles: usize,
    pub visible_overzoomed_tiles: usize,
    pub selection_stats: TileSelectionStats,
    pub counters: TileManagerCounters,
    pub cache_stats: TileCacheStats,
    pub source_diagnostics: Option<TileSourceDiagnostics>,
}
Snapshot of the active tile-layer pipeline for debug/telemetry use.

Fields

layer_name: String

Name of the tile layer providing the snapshot.

visible_tiles: usize

Number of visible tiles in the layer’s last visible set.

visible_loaded_tiles: usize

Number of visible tiles with exact or fallback data loaded.

visible_fallback_tiles: usize

Number of visible tiles currently using fallback imagery.

visible_missing_tiles: usize

Number of visible tiles with no imagery currently available.

visible_overzoomed_tiles: usize

Number of visible tiles rendered as overzoomed.

selection_stats: TileSelectionStats

Per-frame tile-selection stats from the last update.

counters: TileManagerCounters

Cumulative tile-manager counters.

cache_stats: TileCacheStats

Current cache state counts.

source_diagnostics: Option<TileSourceDiagnostics>

Optional source transport diagnostics.