TilePixelRect

Struct TilePixelRect 

pub struct TilePixelRect {
    pub x: u32,
    pub y: u32,
    pub width: u32,
    pub height: u32,
}
Integer pixel-space crop rectangle derived from a fallback texture region.

Fields

x: u32

Left pixel coordinate.

y: u32

Top pixel coordinate.

width: u32

Rectangle width in pixels.

height: u32

Rectangle height in pixels.

Implementations

Source

impl TilePixelRect

pub fn full(width: u32, height: u32) -> Self

Full image coverage.

pub fn from_tiles( target: &TileId, actual: &TileId, width: u32, height: u32, ) -> Option<Self>

Compute the pixel crop rectangle of actual needed to draw target.