pub struct VerticalPerspective { /* private fields */ }Expand description
Near-sided vertical perspective projection onto a tangent plane.
Implementations
Sourceimpl VerticalPerspective
impl VerticalPerspective
Sourcepub fn new(center: GeoCoord, camera_height: f64) -> Self
pub fn new(center: GeoCoord, camera_height: f64) -> Self
Create a vertical perspective projection centered at center.
camera_height is the viewer height above the ellipsoid surface, in
meters, and must be positive.
Sourcepub fn camera_height(&self) -> f64
pub fn camera_height(&self) -> f64
Viewer height above the surface in meters.
Sourcepub fn horizon_central_angle(&self) -> f64
pub fn horizon_central_angle(&self) -> f64
Maximum visible central angle from the projection center, in radians.
Sourcepub fn project_checked(&self, geo: &GeoCoord) -> Option<WorldCoord>
pub fn project_checked(&self, geo: &GeoCoord) -> Option<WorldCoord>
Checked projection that rejects points beyond the visible horizon.