LightingMode

Enum LightingMode 

pub enum LightingMode {
    Default,
    Flat,
}
Lighting mode controlling how lit shaders compute surface illumination.

Mirrors Mapbox GL JS v3’s "lights" style-spec model which supports three light types: ambient, directional, and flat.

Rustial always evaluates one lighting mode per frame. The mode is selected by LightConfig::mode (default: LightingMode::Default which combines ambient + directional).

Variants



Default

Ambient + directional (default). This is the standard 3-D mode used by Mapbox GL JS when both ambient and directional lights are present in the "lights" array.



Flat

Flat / unlit. Surfaces are rendered with no shading, using only the base colour. Equivalent to Mapbox’s "flat" light type.