pub enum StyleError {
DuplicateSourceId(String),
DuplicateLayerId(String),
MissingSource(String),
SourceKindMismatch {
layer_id: String,
source_id: String,
expected: &'static str,
actual: &'static str,
},
MissingSourceLayer {
layer_id: String,
source_id: String,
source_layer: String,
},
}Expand description
Style/runtime errors.
Variants
DuplicateSourceId(String)
Attempted to add a source whose id already exists.
DuplicateLayerId(String)
Attempted to add a layer whose id already exists.
MissingSource(String)
A style layer referenced a source that does not exist.
SourceKindMismatch
A style layer referenced a source of the wrong kind.
Fields
MissingSourceLayer
A vector style layer referenced a source layer that does not exist.