FillStyleLayer

Struct FillStyleLayer 

pub struct FillStyleLayer {
    pub meta: StyleLayerMeta,
    pub source: StyleSourceId,
    pub source_layer: Option<String>,
    pub fill_color: StyleValue<[f32; 4]>,
    pub outline_color: StyleValue<[f32; 4]>,
    pub outline_width: StyleValue<f32>,
    pub fill_pattern: Option<Arc<PatternImage>>,
}
Fill layer style spec.

Fields

meta: StyleLayerMetasource: StyleSourceIdsource_layer: Option<String>

Optional source-layer name for vector-tile-like sources.

fill_color: StyleValue<[f32; 4]>outline_color: StyleValue<[f32; 4]>outline_width: StyleValue<f32>fill_pattern: Option<Arc<PatternImage>>

Optional repeating pattern image for fill-pattern rendering.

When set, the fill is textured with the given pattern instead of a solid colour. Matches MapLibre / Mapbox fill-pattern.

Implementations

Source

impl FillStyleLayer

pub fn new(id: impl Into<String>, source: impl Into<String>) -> Self

Create a fill style layer bound to the given style source id.