LineStyleLayer

Struct LineStyleLayer 

pub struct LineStyleLayer {
    pub meta: StyleLayerMeta,
    pub source: StyleSourceId,
    pub source_layer: Option<String>,
    pub color: StyleValue<[f32; 4]>,
    pub width: StyleValue<f32>,
    pub line_cap: LineCap,
    pub line_join: LineJoin,
    pub miter_limit: f32,
    pub dash_array: Option<Vec<f32>>,
    pub line_gradient: Option<ColorRamp>,
    pub line_pattern: Option<Arc<PatternImage>>,
}
Line layer style spec.

Fields

meta: StyleLayerMetasource: StyleSourceIdsource_layer: Option<String>

Optional source-layer name for vector-tile-like sources.

color: StyleValue<[f32; 4]>width: StyleValue<f32>line_cap: LineCap

Line cap style (default: butt).

line_join: LineJoin

Line join style (default: miter).

miter_limit: f32

Miter limit ratio (default: 2.0).

dash_array: Option<Vec<f32>>

Optional dash pattern [dash, gap, …] in pixels.

line_gradient: Option<ColorRamp>

Optional colour ramp evaluated along the line’s length.

When set, per-vertex colours are overridden by the gradient evaluated at each vertex’s normalized distance [0, 1] along the polyline. Replaces line-color (matching MapLibre / Mapbox line-gradient semantics).

line_pattern: Option<Arc<PatternImage>>

Optional repeating pattern image for textured line rendering.

When set, the line is rendered with a repeating pattern texture instead of a solid colour, matching MapLibre / Mapbox line-pattern semantics.

Implementations

Source

impl LineStyleLayer

pub fn new(id: impl Into<String>, source: impl Into<String>) -> Self

Create a line style layer bound to the given style source id.