TerrainSource

Struct TerrainSource 

pub struct TerrainSource {
    pub enabled: bool,
    pub vertical_exaggeration: f64,
    pub mesh_resolution: u16,
    pub skirt_depth: f64,
    pub cache_capacity: usize,
    pub factory: TerrainSourceFactory,
}
Terrain source entry.

Fields

enabled: bool

Whether terrain is enabled.

vertical_exaggeration: f64

Terrain vertical exaggeration.

mesh_resolution: u16

Terrain mesh resolution.

skirt_depth: f64

Terrain skirt depth in meters.

cache_capacity: usize

Terrain cache capacity.

factory: TerrainSourceFactory

Factory used to build a fresh elevation source each time the style is applied.

Implementations

Source

impl TerrainSource

pub fn new( factory: impl Fn() -> Box<dyn ElevationSource> + Send + Sync + 'static, ) -> Self

Create a terrain source from an elevation-source factory.

pub fn with_cache_capacity(self, cache_capacity: usize) -> Self

Set terrain cache capacity.

pub fn to_terrain_config(&self) -> TerrainConfig

Convert this style terrain source to a terrain config using a fresh source instance.