pub enum SymbolIconTextFit {
None,
Width,
Height,
Both,
}Expand description
Icon sizing mode relative to the label text box.
Variants
None
Keep the icon at its nominal size.
Width
Stretch the icon to match text width.
Height
Stretch the icon to match text height.
Both
Stretch the icon to match both text width and height.