pub enum SymbolTextJustify {
Auto,
Left,
Center,
Right,
}Expand description
Horizontal text justification for symbol labels.
Variants
Auto
Match justification to the effective anchor direction.
Left
Align text toward the left side of the label box.
Center
Center text within the label box.
Right
Align text toward the right side of the label box.