PositionedGlyph

Struct PositionedGlyph 

pub struct PositionedGlyph {
    pub codepoint: char,
    pub glyph_id: u16,
    pub x: f32,
    pub y: f32,
    pub advance: f32,
    pub metrics_width: f32,
    pub metrics_height: f32,
    pub metrics_left: f32,
    pub metrics_top: f32,
    pub font_stack: String,
    pub vertical: bool,
    pub line_index: usize,
}
A positioned glyph after shaping and layout.

Coordinates are in layout units (1/24 em). Multiply by (target_size_px / ONE_EM) to get pixel coordinates.

Fields

codepoint: char

Unicode codepoint.

glyph_id: u16

Glyph ID in the font (for atlas lookup).

x: f32

Horizontal offset from the label anchor in layout units.

y: f32

Vertical offset from the label anchor in layout units.

advance: f32

Glyph advance width in layout units.

metrics_width: f32

Glyph bitmap width in font units (for atlas sizing).

metrics_height: f32

Glyph bitmap height in font units.

metrics_left: f32

Left bearing in font units.

metrics_top: f32

Top bearing in font units.

font_stack: String

Font stack that supplied this glyph.

vertical: bool

Whether this glyph is in vertical orientation.

line_index: usize

Line index (0-based).