TerrainRgbEncoding

Enum TerrainRgbEncoding 

pub enum TerrainRgbEncoding {
    Terrarium,
    Mapbox,
}
Encoding scheme for Terrain-RGB PNG tiles.

Variants



Terrarium

AWS Terrain Tiles / Terrarium. elevation = (R * 256 + G + B / 256) - 32768



Mapbox

Mapbox Terrain-RGB / MapTiler. elevation = -10000 + (R * 65536 + G * 256 + B) * 0.1

Implementations

Source

impl TerrainRgbEncoding

pub fn decode(&self, r: u8, g: u8, b: u8) -> f32

Decode a single pixel’s RGB values to elevation in meters.

Values are clamped to [-500, +9_100] meters to filter out “no data” sentinels (Terrarium encodes (0,0,0) as −32 768 m) and corrupt pixels. −500 m is well below any real land surface (Dead Sea ≈ −430 m) and prevents extreme depressions that create visible gaps between terrain tiles.