pub struct QueriedFeature {
pub layer_id: Option<String>,
pub source_id: Option<String>,
pub source_layer: Option<String>,
pub source_tile: Option<TileId>,
pub feature_id: String,
pub feature_index: usize,
pub geometry: Geometry,
pub properties: HashMap<String, PropertyValue>,
pub state: FeatureState,
pub distance_meters: f64,
pub from_symbol: bool,
}Expand description
A feature returned by source or rendered query APIs.
Fields
layer_id: Option<String>Style layer id or runtime layer name that produced the feature.
source_id: Option<String>Style source id, when known.
source_layer: Option<String>Style source-layer id, when known.
source_tile: Option<TileId>Tile that supplied the feature, when known.
feature_id: StringStable feature id.
feature_index: usizeSource-local feature index.
geometry: GeometryFeature geometry.
properties: HashMap<String, PropertyValue>Feature properties.
state: FeatureStateMutable feature-state snapshot.
distance_meters: f64Distance from the query position in meters.
from_symbol: boolWhether the hit came from the rendered symbol representation.