pub struct PooledTileSource { /* private fields */ }Expand description
A TileSource that fetches tiles over HTTP with concurrency limiting
and viewport-center priority ordering via FetchPool.
Implementations
Sourceimpl PooledTileSource
impl PooledTileSource
Sourcepub fn new(
url_template: impl Into<String>,
client: Box<dyn HttpClient>,
max_concurrent: usize,
) -> Self
pub fn new( url_template: impl Into<String>, client: Box<dyn HttpClient>, max_concurrent: usize, ) -> Self
Create a new pooled tile source without image decoding.
Response bodies are assumed to be raw RGBA8 256x256 pixel data.
For real tile providers use with_decoder.
Sourcepub fn with_decoder(
url_template: impl Into<String>,
client: Box<dyn HttpClient>,
max_concurrent: usize,
decoder: Box<dyn TileDecoder>,
) -> Self
pub fn with_decoder( url_template: impl Into<String>, client: Box<dyn HttpClient>, max_concurrent: usize, decoder: Box<dyn TileDecoder>, ) -> Self
Create a new pooled tile source with a TileDecoder.