TileLifecycleRecord

Struct TileLifecycleRecord 

pub struct TileLifecycleRecord {
Show 15 fields pub tile: TileId, pub first_selected_frame: Option<u64>, pub first_queued_frame: Option<u64>, pub first_dispatched_frame: Option<u64>, pub first_completed_frame: Option<u64>, pub first_decoded_frame: Option<u64>, pub first_promoted_frame: Option<u64>, pub first_renderable_frame: Option<u64>, pub first_exact_frame: Option<u64>, pub first_fallback_frame: Option<u64>, pub queued_frames_to_dispatch: Option<u64>, pub in_flight_frames_to_complete: Option<u64>, pub completion_to_visible_use_frames: Option<u64>, pub last_event_frame: u64, pub terminal_event: Option<TileLifecycleEventKind>,
}
Per-tile lifecycle record with first-observed timings.

Fields

tile: TileId

Tile tracked by this record.

first_selected_frame: Option<u64>

First frame where the tile was selected.

first_queued_frame: Option<u64>

First frame where the tile entered the pending queue.

first_dispatched_frame: Option<u64>

First frame where the tile was dispatched.

first_completed_frame: Option<u64>

First frame where the tile completed.

first_decoded_frame: Option<u64>

First frame where the tile payload passed validation / decode.

first_promoted_frame: Option<u64>

First frame where the tile was promoted to the cache.

first_renderable_frame: Option<u64>

First frame where the tile became renderable in the visible set.

first_exact_frame: Option<u64>

First frame where the tile was used as the exact visible tile.

first_fallback_frame: Option<u64>

First frame where the tile was used as fallback imagery.

queued_frames_to_dispatch: Option<u64>

Frame delta between first queue and first dispatch.

in_flight_frames_to_complete: Option<u64>

Frame delta between first dispatch and first completion.

completion_to_visible_use_frames: Option<u64>

Frame delta between first completion and first visible renderable use.

last_event_frame: u64

Most recent frame where any lifecycle event was recorded.

terminal_event: Option<TileLifecycleEventKind>

Terminal transition, if the record has completed.