TileManagerCounters

Struct TileManagerCounters 

pub struct TileManagerCounters {
    pub frames: u64,
    pub budget_hit_frames: u64,
    pub dropped_by_budget: u64,
    pub exact_cache_hits: u64,
    pub fallback_hits: u64,
    pub child_fallback_hits: u64,
    pub cache_misses: u64,
    pub requested_tiles: u64,
    pub speculative_requested_tiles: u64,
    pub cancelled_stale_pending: u64,
    pub cancelled_evicted_pending: u64,
}
Cumulative counters for long-running tile-manager diagnostics.

Fields

frames: u64

Total number of frames processed by the manager.

budget_hit_frames: u64

Total number of times the visible tile budget was hit.

dropped_by_budget: u64

Total number of candidate tiles dropped by the budget.

exact_cache_hits: u64

Total number of exact visible-tile cache hits.

fallback_hits: u64

Total number of visible fallback hits.

child_fallback_hits: u64

Total number of visible child-fallback hits.

cache_misses: u64

Total number of visible cache misses.

requested_tiles: u64

Total number of requested tiles.

speculative_requested_tiles: u64

Total number of speculative prefetch tile requests.

cancelled_stale_pending: u64

Total number of stale pending requests cancelled.

cancelled_evicted_pending: u64

Total number of pending requests cancelled because their entries were evicted.