TileSourceFailureDiagnostics

Struct TileSourceFailureDiagnostics 

pub struct TileSourceFailureDiagnostics {
    pub transport_failures: u64,
    pub http_status_failures: u64,
    pub not_found_failures: u64,
    pub decode_failures: u64,
    pub timeout_failures: u64,
    pub forced_cancellations: u64,
    pub ignored_completed_responses: u64,
}
Optional runtime diagnostics exposed by a tile source.

Fields

transport_failures: u64

Number of transport-level failures reported by the HTTP client.

http_status_failures: u64

Number of non-404 HTTP status failures.

not_found_failures: u64

Number of 404 Not Found tile responses.

decode_failures: u64

Number of decode failures returned by the tile decoder.

timeout_failures: u64

Number of transport failures classified as timeouts.

forced_cancellations: u64

Number of requests force-cancelled by the engine/source path.

ignored_completed_responses: u64

Number of completed responses ignored because their request mapping was removed.