TileTextureRegion

Struct TileTextureRegion 

pub struct TileTextureRegion {
    pub u_min: f32,
    pub v_min: f32,
    pub u_max: f32,
    pub v_max: f32,
}
Normalized texture-space region within an actual tile image that maps to a target tile.

Fields

u_min: f32

Minimum U in normalized texture coordinates.

v_min: f32

Minimum V in normalized texture coordinates.

u_max: f32

Maximum U in normalized texture coordinates.

v_max: f32

Maximum V in normalized texture coordinates.

Implementations

Source

impl TileTextureRegion

pub const FULL: Self

Full texture coverage.

pub fn from_tiles(target: &TileId, actual: &TileId) -> Self

Compute the normalized texture-space region of actual needed to draw target.

pub fn is_full(&self) -> bool

Whether this region covers the full source texture.

pub fn from_child_tile(target: &TileId, child: &TileId) -> Option<Self>

Compute the texture region for rendering a child tile (at a higher zoom) into the grid cell of a target tile (at a lower zoom).

This is the inverse of from_tiles which handles the parent-fallback (overzoom) case. For child-fallback (underzoom), the child’s full texture maps into a sub-region of the target’s grid cell.

Returns

None if child is not a descendant of target.