StyleDocument

Struct StyleDocument 

pub struct StyleDocument { /* private fields */ }
A style document containing source registry, ordered layers, and optional terrain source.

Implementations

Source

impl StyleDocument

pub fn new() -> Self

Create an empty style document.

pub fn add_source( &mut self, id: impl Into<String>, source: StyleSource, ) -> Result<(), StyleError>

Register a named source.

pub fn set_source(&mut self, id: impl Into<String>, source: StyleSource)

Upsert a named source.

pub fn remove_source(&mut self, id: &str) -> Option<StyleSource>

Remove a source, returning it if present.

pub fn source(&self, id: &str) -> Option<&StyleSource>

Look up a source by id.

pub fn sources(&self) -> impl Iterator<Item = (&str, &StyleSource)>

Iterate registered sources.

pub fn set_terrain_source(&mut self, source_id: Option<impl Into<String>>)

Set the terrain source id used to configure MapState terrain.

pub fn terrain_source(&self) -> Option<&str>

Return the configured terrain source id, if any.

pub fn set_projection(&mut self, projection: StyleProjection)

Set the top-level style projection.

pub fn projection(&self) -> StyleProjection

Return the top-level style projection.

pub fn set_fog(&mut self, fog: Option<FogConfig>)

Set the fog/atmosphere configuration.

pub fn fog(&self) -> Option<&FogConfig>

Return the fog/atmosphere configuration, if any.

pub fn set_lights(&mut self, lights: Option<LightConfig>)

Set the lighting configuration.

pub fn lights(&self) -> Option<&LightConfig>

Return the lighting configuration, if any.

pub fn set_sky(&mut self, sky: Option<SkyConfig>)

Set the sky / atmosphere configuration.

pub fn sky(&self) -> Option<&SkyConfig>

Return the sky / atmosphere configuration, if any.

pub fn set_transition(&mut self, spec: TransitionSpec)

Set the global default transition timing.

pub fn transition(&self) -> TransitionSpec

Return the global default transition timing.

pub fn add_layer(&mut self, layer: StyleLayer) -> Result<(), StyleError>

Append a style layer to the ordered layer stack.

pub fn insert_layer_before( &mut self, before_id: &str, layer: StyleLayer, ) -> Result<(), StyleError>

Insert a style layer before another style layer id.

pub fn move_layer_before(&mut self, layer_id: &str, before_id: &str) -> bool

Move an existing style layer before another style layer.

pub fn remove_layer(&mut self, layer_id: &str) -> Option<StyleLayer>

Remove a style layer by id.

pub fn layer(&self, layer_id: &str) -> Option<&StyleLayer>

Get a style layer by id.

pub fn layer_mut(&mut self, layer_id: &str) -> Option<&mut StyleLayer>

Get a mutable style layer by id.

pub fn layers(&self) -> &[StyleLayer]

Iterate style layers in render order.

pub fn to_runtime_layers(&self) -> Result<Vec<Box<dyn Layer>>, StyleError>

Evaluate the style document to a concrete runtime layer stack.

pub fn to_runtime_layers_with_context( &self, ctx: StyleEvalContext, ) -> Result<Vec<Box<dyn Layer>>, StyleError>

Evaluate the style document to a concrete runtime layer stack using a context.

pub fn to_terrain_config( &self, ) -> Result<Option<(TerrainConfig, usize)>, StyleError>

Evaluate the configured terrain source to a concrete terrain config.

pub fn source_is_used(&self, source_id: &str) -> bool

Return true if any style layer or terrain configuration uses the given source id.

pub fn layer_ids_using_source(&self, source_id: &str) -> Vec<&str>

Return the ordered list of style layer ids that reference the given source id.