pub struct FontRegistry { /* private fields */ }Expand description
Registry of loaded fonts keyed by font stack names.
A “font stack” is a comma-separated list of font family names
(e.g. "Noto Sans Regular, Arial Unicode MS Bold"). The registry
resolves the first available font for each stack.
Implementations
Sourceimpl FontRegistry
impl FontRegistry
Sourcepub fn register(&mut self, family_name: impl Into<String>, font: OwnedFont)
pub fn register(&mut self, family_name: impl Into<String>, font: OwnedFont)
Register a font under a family name.
Sourcepub fn font_count(&self) -> usize
pub fn font_count(&self) -> usize
How many individual fonts are registered.
Sourcepub fn resolve_stack(&mut self, font_stack: &str) -> Option<&str>
pub fn resolve_stack(&mut self, font_stack: &str) -> Option<&str>
Resolve a font stack to the first available font.
Returns the family name of the resolved font, or None if no font
in the stack is registered.